@@ -409,8 +409,8 @@ void VkService::Sink::sendCompleted()
 VkService::VkService(const QMailAccountId &accountId)
     : QMailMessageService(),
       _client(this),
-      _source(new Source(this)),
-      _sink(new Sink(this))
+      _source(new Source(this))//,
+      //_sink(new Sink(this))
 {
     //qDebug() << "VkService for id=" << (accountId);
     connect(&_client, SIGNAL(progressChanged(uint, uint)),
@@ -434,7 +434,7 @@ VkService::VkService(const QMailAccountId &accountId)
 VkService::~VkService()
 {
     delete _source;
-    delete _sink;
+   // delete _sink;
 }
 
 QString VkService::service() const
@@ -451,22 +451,23 @@ bool VkService::hasSource() const
 {
     return true;
 }
-
+/*
 bool VkService::hasSink() const
 {
-    return true;
+    return false;
 }
-
+*/
 QMailMessageSource &VkService::source() const
 {
     return *_source;
 }
 
+/*
 QMailMessageSink &VkService::sink() const
 {
     return *_sink;
 }
-
+*/
 bool VkService::available() const
 {
     return true;
@@ -532,7 +533,7 @@ QString VkConfigurator::service() const
 
 QString VkConfigurator::displayName() const
 {
-    return QCoreApplication::instance()->translate("QMailMessageService", "VKontakte");
+    return QCoreApplication::instance()->translate("QMailMessageService", "Vkontakte");
 }
 
 #ifndef QMF_NO_MESSAGE_SERVICE_EDITOR
@@ -551,6 +552,8 @@ QMailMessageServiceEditor *VkConfigurator::createEditor(
 }
 #endif
 
+Q_EXPORT_PLUGIN2(vk,VkServicePlugin)
+
 VkServicePlugin::VkServicePlugin()
     : QMailMessageServicePlugin()
 {
@@ -565,8 +568,9 @@ bool VkServicePlugin::supports(
         QMailMessageServiceFactory::ServiceType type) const
 {
     return (type == QMailMessageServiceFactory::Source)
-            || (type == QMailMessageServiceFactory::Sink)
-            ||  (type == QMailMessageServiceFactory::Any);
+            //|| (type == QMailMessageServiceFactory::Sink)
+            //||  (type == QMailMessageServiceFactory::Any)
+            ;
 }
 
 bool VkServicePlugin::supports(QMailMessage::MessageType type) const
@@ -585,31 +589,3 @@ QMailMessageServiceConfigurator *VkServicePlugin::createServiceConfigurator()
 }
 
 #include "vkservice.moc"
-
-#  define MY_PLUGIN_VERIFICATION_DATA \
-	            static const char *my_plugin_verification_data = \
-      "pattern=""QT_PLUGIN_VERIFICATION_DATA""\n" \
-      "version="QT_VERSION_STR"\n" \
-      "debug="QPLUGIN_DEBUG_STR"\n" \
-      "buildkey=""armv6 linux g++-4 full-config";
-
-#  define MY_EXPORT_PLUGIN2(PLUGIN, PLUGINCLASS)      \
-	                    MY_PLUGIN_VERIFICATION_DATA \
-            Q_EXTERN_C Q_DECL_EXPORT \
-            const char * Q_STANDARD_CALL qt_plugin_query_verification_data() \
-            { return my_plugin_verification_data; } \
-            Q_EXTERN_C Q_DECL_EXPORT QT_PREPEND_NAMESPACE(QObject) * Q_STANDARD_CALL qt_plugin_instance() \
-            Q_PLUGIN_INSTANCE(PLUGINCLASS)
-
-/* Adding plugin debug string */
-#ifdef QPLUGIN_DEBUG_STR
-#    undef QPLUGIN_DEBUG_STR
-#endif
-#define QPLUGIN_DEBUG_STR "true"
-
-#ifdef Q_WS_MAEMO5
-MY_EXPORT_PLUGIN2(vk,VkServicePlugin)
-#else
-Q_EXPORT_PLUGIN2(vk,VkServicePlugin)
-#endif
-	
